from datetime import datetime

from cpl_core.dependency_injection import ServiceProviderABC
from cpl_discord.service import DiscordBotServiceABC

from bot_data.abc.history_table_abc import HistoryTableABC


class UserJoinedVoiceChannelHistory(HistoryTableABC):
    def __init__(
        self,
        user: int,
        channel_id: int,
        joined_on: datetime,
        leaved_on: datetime,
        deleted: bool,
        date_from: str,
        date_to: str,
        id=0,
    ):
        HistoryTableABC.__init__(self)

        self._join_id = id
        self._channel_id = channel_id
        self._user = user
        self._joined_on = joined_on
        self._leaved_on = leaved_on

        self._deleted = deleted
        self._date_from = date_from
        self._date_to = date_to

    @property
    def id(self) -> int:
        return self._join_id

    @property
    def channel_id(self) -> int:
        return self._channel_id

    @property
    @ServiceProviderABC.inject
    def channel_name(self, bot: DiscordBotServiceABC) -> str:
        channel = bot.get_channel(self.channel_id)
        if channel is None:
            return ""
        return channel.name

    @property
    def user(self) -> int:
        return self._user

    @property
    def time(self) -> float:
        if self._leaved_on is None or self._joined_on is None:
            return 0
        return round((self.leaved_on - self.joined_on).total_seconds() / 3600, 2)

    @property
    def joined_on(self) -> datetime:
        return self._joined_on

    @property
    def leaved_on(self) -> datetime:
        return self._leaved_on
